Package: DLFM
Type: Package
Version: 0.2.4
Title: Distributed Laplace Factor Model
Authors@R: 
    c(person(given = "Guangbao",
             family = "Guo",
             role = c("aut", "cre"),
             email = "ggb11111111@163.com"),
      person(given = "Siqi",
             family = "Liu",
             role = "aut"))
Description: Distributed estimation method is based on a Laplace factor model
    to solve the estimates of load and specific variance. The philosophy of
    the package is described in Guangbao Guo. (2022).
    <doi:10.1007/s00180-022-01270-z>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: MASS, LaplacesDemon, matrixcalc, stats
Depends: R (>= 3.5.0)
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
LazyData: true
BuildManual: yes
NeedsCompilation: no
Language: en-US
Repository: CRAN
Packaged: 2026-05-13 13:47:08 UTC; R7000
Author: Guangbao Guo [aut, cre],
  Siqi Liu [aut]
Maintainer: Guangbao Guo <ggb11111111@163.com>
Date/Publication: 2026-05-18 02:30:02 UTC
Built: R 4.6.0; ; 2026-05-18 05:29:46 UTC; unix
