# Generated by roxygen2: do not edit by hand

export(DGulPC)
export(DIPC)
export(DPC)
export(DPPC)
export(DSAPC)
export(Dfactor.tests)
export(FanPC)
export(Ftest)
export(GulPC)
export(IPC)
export(LFM)
export(PC)
export(PPC)
export(SAPC)
export(calculate_DAA)
export(estimate_AD_from_OSDR)
export(factor.tests)
export(frobenius.norm)
export(generate_asymmetric_laplace)
export(generate_multivariate_laplace)
export(generate_skew_laplace)
export(online_sir_lfm)
export(osdr_lfm)
importFrom(LaplacesDemon,is.positive.definite)
importFrom(LaplacesDemon,is.square.matrix)
importFrom(LaplacesDemon,is.symmetric.matrix)
importFrom(LaplacesDemon,lower.triangle)
importFrom(LaplacesDemon,rallaplace)
importFrom(LaplacesDemon,rlaplace)
importFrom(LaplacesDemon,rllaplace)
importFrom(LaplacesDemon,rslaplace)
importFrom(LaplacesDemon,upper.triangle)
importFrom(MASS,ginv)
importFrom(MASS,mvrnorm)
importFrom(matrixcalc,frobenius.norm)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,lm)
importFrom(stats,p.adjust)
importFrom(stats,pcauchy)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,qcauchy)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rexp)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,runif)
